@@ -25,7 +25,8 @@ from .pacman import (
 from .args import PikaurArgs, parse_args
 from .pprint import (
     color_line, bold_line, color_enabled,
-    print_stdout, print_stderr, print_error, print_debug,
+    print_stdout, print_stderr, print_error, create_debug_logger,
+    ColorsHighlight,
 )
 from .prompt import (
     retry_interactive_command_or_exit, ask_to_continue,
@@ -43,8 +44,7 @@ from .urllib import wrap_proxy_env
 from .filelock import FileLock
 
 
-def debug(msg: Any) -> None:
-    print_debug(f"{color_line('build', 5)}: {str(msg)}")
+_debug = create_debug_logger('build')
 
 
 class PkgbuildChanged(Exception):
@@ -98,6 +98,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
     repo_path: str
     pkgbuild_path: str
     build_dir: str
+    build_gpgdir: str
     built_packages_paths: Dict[str, str]
 
     reviewed = False
@@ -145,6 +146,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             raise NotImplementedError('Either `package_names` or `pkgbuild_path` should be set')
 
         self.build_dir = os.path.join(BUILD_CACHE_PATH, self.package_base)
+        self.build_gpgdir = self.args.build_gpgdir
         self.built_packages_paths = {}
         self.keep_build_dir = self.args.keepbuild or (
             is_devel_pkg(self.package_base) and PikaurConfig().build.KeepDevBuildDir.get_bool()
@@ -268,7 +270,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         ):
             return
         print_stdout('{} {}...'.format(  # pylint: disable=consider-using-f-string
-            color_line('::', 15),
+            color_line('::', ColorsHighlight.white),
             translate_many(
                 "Downloading the latest sources for a devel package {}",
                 "Downloading the latest sources for devel packages {}",
@@ -280,7 +282,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         pkgver_result = joined_spawn(
             isolate_root_cmd(
                 MakePkgCommand.get() + [
-                    '--nobuild', '--noprepare', '--nocheck', '--nodeps'
+                    '--nobuild', '--nocheck', '--nodeps'
                 ],
                 cwd=self.build_dir
             ),
@@ -383,7 +385,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             return
 
         print_stderr('{} {}:'.format(  # pylint: disable=consider-using-f-string
-            color_line('::', 13),
+            color_line('::', ColorsHighlight.purple),
             translate("Installing already built dependencies for {}").format(
                 bold_line(', '.join(self.package_names)))
         ))
@@ -452,7 +454,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
                 len(self.built_packages_paths) == len(self.package_names)
         ):
             print_stderr("{} {}\n".format(  # pylint: disable=consider-using-f-string
-                color_line("::", 10),
+                color_line("::", ColorsHighlight.green),
                 translate_many(
                     "Package {pkg} is already built. Pass '--rebuild' flag to force the build.",
                     "Packages {pkg} are already built. Pass '--rebuild' flag to force the build.",
@@ -529,7 +531,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             return
 
         print_stderr('{} {}:'.format(  # pylint: disable=consider-using-f-string
-            color_line('::', 13),
+            color_line('::', ColorsHighlight.purple),
             translate("Installing repository dependencies for {}").format(
                 bold_line(', '.join(self.package_names)))
         ))
@@ -561,15 +563,15 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
         if not self._local_pkgs_wo_build_deps:
             return
 
-        debug("Gonna compute diff of installed pkgs")
+        _debug("Gonna compute diff of installed pkgs")
         deps_packages_installed = self._local_pkgs_with_build_deps.difference(
             self._local_pkgs_wo_build_deps
         )
         deps_packages_removed = self._local_pkgs_wo_build_deps.difference(
             self._local_pkgs_with_build_deps
         )
-        debug(f"{deps_packages_installed=}")
-        debug(f"{deps_packages_removed=}")
+        _debug(f"{deps_packages_installed=}")
+        _debug(f"{deps_packages_removed=}")
         if not deps_packages_installed:
             return
 
@@ -601,7 +603,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             return
 
         print_stderr('{} {}:'.format(  # pylint: disable=consider-using-f-string
-            color_line('::', 13),
+            color_line('::', ColorsHighlight.purple),
             translate("Removing already installed dependencies for {}").format(
                 bold_line(', '.join(self.package_names)))
         ))
@@ -654,7 +656,7 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             makepkg_args.append('--nocolor')
 
         print_stderr('\n{} {}:'.format(  # pylint: disable=consider-using-f-string
-            color_line('::', 13),
+            color_line('::', ColorsHighlight.purple),
             translate('Starting the build')
         ))
         build_succeeded = False
@@ -671,16 +673,23 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
                 cmd_args += ['--ignorearch']
             if skip_check:
                 cmd_args += ['--nocheck']
-            cmd_args = isolate_root_cmd(cmd_args, cwd=self.build_dir)
+
+            env = {}
+            if self.build_gpgdir != '':
+                env['GNUPGHOME'] = self.build_gpgdir
+
+            cmd_args = isolate_root_cmd(cmd_args, cwd=self.build_dir, env=env)
             spawn_kwargs: Dict[str, Any] = {}
             if self.args.hide_build_log:
                 spawn_kwargs = dict(
                     stdout=subprocess.PIPE,
                     stderr=subprocess.PIPE
                 )
+
             result = interactive_spawn(
                 cmd_args,
                 cwd=self.build_dir,
+                env={**os.environ, **env},
                 **spawn_kwargs
             )
             print_stdout()
@@ -688,16 +697,21 @@ class PackageBuild(DataType):  # pylint: disable=too-many-public-methods
             if build_succeeded:
                 break
 
-            print_stderr(color_line(translate("Command '{}' failed to execute.").format(
-                ' '.join(cmd_args)
-            ), 9))
+            print_stderr(
+                color_line(
+                    translate("Command '{}' failed to execute.").format(
+                        ' '.join(cmd_args)
+                    ),
+                    ColorsHighlight.red
+                )
+            )
             if PikaurConfig().build.SkipFailedBuild.get_bool():
                 answer = translate("s")
             elif self.args.noconfirm:
                 answer = translate("a")
             else:  # pragma: no cover
                 prompt = '{} {}\n{}\n> '.format(
-                    color_line('::', 11),
+                    color_line('::', ColorsHighlight.yellow),
                     translate("Try recovering?"),
                     "\n".join((
                         translate("[R] retry build"),
