@@ -12,7 +12,7 @@ import shutil
 import atexit
 import io
 from argparse import ArgumentError
-from typing import List, Optional, Callable
+from typing import Optional, Callable
 
 import pyalpm
 
@@ -22,20 +22,18 @@ from .args import (
 )
 from .help_cli import cli_print_help
 from .core import (
-    DEFAULT_INPUT_ENCODING, InstallInfo,
+    DEFAULT_INPUT_ENCODING,
     spawn, interactive_spawn, remove_dir, check_runtime_deps,
     running_as_root, sudo, isolate_root_cmd, run_with_sudo_loop,
 )
 from .pprint import (
     color_line, bold_line,
     print_stderr, print_stdout,
-    print_error, print_warning, print_debug,
+    print_error, print_warning,
+    create_debug_logger, ColorsHighlight,
 )
-from .print_department import (
-    pretty_format_upgradeable, print_version,
-    print_ignored_package,
-)
-from .updates import find_repo_upgradeable, find_aur_updates
+from .print_department import print_version
+from .updates import print_upgradeable
 from .prompt import ask_to_continue, get_multiple_numbers_input, NotANumberInput
 from .config import (
     BUILD_CACHE_PATH, PACKAGE_CACHE_PATH, CACHE_ROOT, CONFIG_PATH,
@@ -46,7 +44,6 @@ from .pikspect import TTYRestore, PikspectSignalHandler
 from .install_cli import InstallPackagesCLI
 from .search_cli import cli_search_packages
 from .info_cli import cli_info_packages
-from .pacman import PacmanConfig, get_ignored_pkgnames_from_patterns
 from .urllib import init_proxy, ProxyInitSocks5Error
 from .getpkgbuild_cli import cli_getpkgbuild
 
@@ -63,6 +60,8 @@ def init_readline() -> None:
 
 init_readline()
 
+_debug = create_debug_logger('main')
+
 
 def init_output_encoding() -> None:
     for attr in ('stdout', 'stderr'):
@@ -85,32 +84,7 @@ init_output_encoding()
 
 
 def cli_print_upgradeable() -> None:
-    args = parse_args()
-    updates: List[InstallInfo] = []
-    if not args.repo:
-        aur_updates, _not_found_aur_pkgs = find_aur_updates()
-        updates += aur_updates
-    if not args.aur:
-        updates += find_repo_upgradeable()
-    if not updates:
-        return
-    ignored_pkg_names = get_ignored_pkgnames_from_patterns(
-        [pkg.name for pkg in updates],
-        args.ignore + PacmanConfig().options.get('IgnorePkg', [])
-    )
-    for pkg in updates[:]:
-        if pkg.name in ignored_pkg_names:
-            updates.remove(pkg)
-            print_ignored_package(install_info=pkg)
-    if args.quiet:
-        print_stdout('\n'.join([
-            pkg_update.name for pkg_update in updates
-        ]))
-    else:
-        print_stdout(pretty_format_upgradeable(
-            updates,
-            print_repo=PikaurConfig().sync.AlwaysShowPkgOrigin.get_bool()
-        ))
+    print_upgradeable()
 
 
 def cli_install_packages() -> None:
@@ -131,7 +105,7 @@ def cli_clean_packages_cache() -> None:
             if minimal_clean_level <= args.clean and os.path.exists(directory):
                 print_stdout(f"\n{message}: {directory}")
                 if ask_to_continue(text='{} {}'.format(  # pylint: disable=consider-using-f-string
-                        color_line('::', 12),
+                        color_line('::', ColorsHighlight.blue),
                         bold_line(translate("Do you want to remove all files?"))
                 )):
                     remove_dir(directory)
@@ -249,7 +223,7 @@ def cli_entry_point() -> None:  # pylint: disable=too-many-statements
         require_sudo = True
 
     if pikaur_operation:
-        print_debug(f"Pikaur operation found for {sys.argv=}: {pikaur_operation.__name__}")
+        _debug(f"Pikaur operation found for {sys.argv=}: {pikaur_operation.__name__}")
         if require_sudo and args.dynamic_users and not running_as_root():
             # Restart pikaur with sudo to use systemd dynamic users
             restart_args = sys.argv[:]
@@ -271,8 +245,8 @@ def cli_entry_point() -> None:  # pylint: disable=too-many-statements
                 run_with_sudo_loop(pikaur_operation)
     else:
         # Just bypass all the args to pacman
-        print_debug(f"Pikaur operation not found for {sys.argv=}")
-        print_debug(args)
+        _debug(f"Pikaur operation not found for {sys.argv=}")
+        _debug(args)
         pacman_args = [
             PikaurConfig().misc.PacmanPath.get_str(),
         ] + args.raw_without_pikaur_specific
