@@ -17,8 +17,8 @@ from time import sleep
 from typing import List, Dict, TextIO, BinaryIO, Callable, Optional, Union
 
 from .pprint import (
-    PrintLock, print_debug, print_stderr,
-    get_term_width, bold_line, color_line,
+    PrintLock, print_stderr, create_debug_logger,
+    get_term_width, bold_line, color_line, ColorsHighlight,
 )
 from .pacman_i18n import _p
 from .args import parse_args
@@ -32,8 +32,7 @@ SMALL_TIMEOUT = 0.01
 TcAttrsType = List[Union[int, List[Union[bytes, int]]]]
 
 
-def _debug(message):
-    print_debug(f"pikspect: {message}", lock=False)
+_debug = create_debug_logger('pikspect', lock=False)
 
 
 class TTYRestore():  # pragma: no cover
@@ -58,7 +57,7 @@ class TTYRestore():  # pragma: no cover
             try:
                 termios.tcsetattr(sys.stdin.fileno(), termios.TCSANOW, what)
             except termios.error as exc:
-                print_debug(','.join(str(arg) for arg in exc.args))
+                _debug(','.join(str(arg) for arg in exc.args))
 
     @classmethod
     def restore(cls, *_whatever) -> None:
@@ -194,7 +193,7 @@ class PikspectPopen(subprocess.Popen):
         self.pty_user_master, self.pty_user_slave = pty.openpty()
         self.pty_cmd_master, self.pty_cmd_slave = pty.openpty()
 
-        super().__init__(  # type: ignore[call-arg]
+        super().__init__(
             args=args,
             stdin=self.pty_user_slave,
             stdout=self.pty_cmd_slave,
@@ -416,7 +415,10 @@ def pikspect(
         proc.add_answers(extra_questions)
 
     if parse_args().print_commands:
-        print_stderr(color_line('pikspect => ', 14) + ' '.join(cmd))
+        print_stderr(
+            color_line('pikspect => ', ColorsHighlight.cyan) +
+            ' '.join(cmd)
+        )
     proc.run()
     return proc
 
