@@ -4,6 +4,7 @@ import sys
 import shutil
 from threading import Lock
 from string import printable
+import typing as t
 from typing import List, Optional, TextIO, Any
 
 from .i18n import translate
@@ -56,6 +57,28 @@ def print_stderr(message='', end='\n', flush=False, lock=True) -> None:
     _print(sys.stderr, message=message, end=end, flush=flush, lock=lock)
 
 
+class Colors:
+    black = 0
+    red = 1
+    green = 2
+    yellow = 3
+    blue = 4
+    purple = 5
+    cyan = 6
+    white = 7
+
+
+class ColorsHighlight:
+    black = 8
+    red = 9
+    green = 10
+    yellow = 11
+    blue = 12
+    purple = 13
+    cyan = 14
+    white = 15
+
+
 def color_line(line: str, color_number: int, reset=True, force=False) -> str:
     if not color_enabled() and not force:
         return line
@@ -78,14 +101,14 @@ def bold_line(line: str) -> str:
 
 def print_warning(message: str = '') -> None:
     print_stderr(' '.join([
-        color_line(':: ' + translate("warning:"), 11),
+        color_line(':: ' + translate("warning:"), ColorsHighlight.yellow),
         message
     ]))
 
 
 def print_error(message: str) -> None:
     print_stderr(' '.join([
-        color_line(':: ' + translate("error:"), 9),
+        color_line(':: ' + translate("error:"), ColorsHighlight.red),
         message
     ]))
 
@@ -98,7 +121,7 @@ def print_debug(message: Any, lock=True) -> None:
         # to avoid mixing together with pacman's debug messages:
         prefix = translate("pikaur debug:")
     print_stderr(' '.join([
-        color_line(':: ' + prefix, 6),
+        color_line(':: ' + prefix, Colors.cyan),
         str(message)
     ]), lock=lock)
 
@@ -154,3 +177,44 @@ def range_printable(text: str, start: int = 0, end: Optional[int] = None) -> str
         if counter >= end:
             break
     return result
+
+
+class DebugColorCounter:
+
+    # cyan is purposely skipped as it's used in print_debug itself,
+    # highlight-red is purposely skipped as it's used in print_error,
+    # highlight-yellow is purposely skipped as it's used in print_warning:
+    colors = [
+        Colors.red,
+        Colors.green,
+        Colors.yellow,
+        Colors.blue,
+        Colors.purple,
+        Colors.white,
+        ColorsHighlight.green,
+        ColorsHighlight.blue,
+        ColorsHighlight.purple,
+        ColorsHighlight.cyan,
+        ColorsHighlight.white,
+    ]
+    _current_color_idx = 0
+
+    @classmethod
+    def next(cls) -> int:
+        color = cls.colors[cls._current_color_idx]
+        cls._current_color_idx += 1
+        if cls._current_color_idx >= len(cls.colors):
+            cls._current_color_idx = 0
+        return color
+
+
+def create_debug_logger(module_name: str, **kwargs) -> t.Callable[..., None]:
+    color = DebugColorCounter.next()
+
+    def debug(msg: Any, *args2, **kwargs2) -> None:
+        kwargs2.update(kwargs)
+        print_debug(
+            f"{color_line(module_name, color)}: {str(msg)}",
+            *args2, **kwargs2
+        )
+    return debug
