@@ -2,8 +2,10 @@
 
 import sys
 from datetime import datetime
+from fnmatch import fnmatch
 from typing import (
     TYPE_CHECKING, List, Tuple, Iterable, Union, Dict, Optional, Sequence,
+    overload,
 )
 
 import pyalpm
@@ -306,158 +308,257 @@ def pretty_format_upgradeable(  # pylint: disable=too-many-statements
     ])
 
 
+class SysupgradePrettyFormatter:
+
+    def __init__(
+        self,
+        install_info: 'InstallInfoFetcher',
+        verbose,
+        manual_package_selection
+    ):
+        self.color = True
+        self.install_info = install_info
+        self.verbose = verbose
+
+        self.repo_packages_updates: List[RepoInstallInfo] = \
+            install_info.repo_packages_install_info[::]
+        self.thirdparty_repo_packages_updates: List[RepoInstallInfo] = \
+            install_info.thirdparty_repo_packages_install_info[::]
+        self.aur_updates: List[AURInstallInfo] = \
+            install_info.aur_updates_install_info[::]
+        self.repo_replacements: List[RepoInstallInfo] = \
+            install_info.repo_replacements_install_info[::]
+        self.thirdparty_repo_replacements: List[RepoInstallInfo] = \
+            install_info.thirdparty_repo_replacements_install_info[::]
+
+        self.new_repo_deps: List[RepoInstallInfo] = \
+            install_info.new_repo_deps_install_info[::]
+        self.new_thirdparty_repo_deps: List[RepoInstallInfo] = \
+            install_info.new_thirdparty_repo_deps_install_info[::]
+        self.new_aur_deps: List[AURInstallInfo] = \
+            install_info.aur_deps_install_info[::]
+
+        if manual_package_selection:
+            self.color = False
+            self.new_repo_deps = []
+            self.new_thirdparty_repo_deps = []
+            self.new_aur_deps = []
+
+        self.all_install_info_lists: Sequence[
+            Union[
+                List[AURInstallInfo],
+                List[RepoInstallInfo]
+            ]
+        ] = [
+            self.repo_packages_updates,
+            self.thirdparty_repo_packages_updates,
+            self.aur_updates,
+            self.repo_replacements,
+            self.thirdparty_repo_replacements,
+            self.new_repo_deps,
+            self.new_thirdparty_repo_deps,
+            self.new_aur_deps,
+        ]
+
+        self.config = PikaurConfig()
+        self.result: List[str] = []
+
+    def _color_line(self, line, *args, **kwargs) -> str:
+        return color_line(line, *args, **kwargs) if self.color else line
+
+    def _bold_line(self, line) -> str:
+        return bold_line(line) if self.color else line
+
+    def pretty_format_upgradeable(
+            self,
+            install_infos: Sequence[InstallInfo],
+            print_repo=None
+    ) -> str:
+        if print_repo is None:
+            print_repo = self.config.sync.AlwaysShowPkgOrigin.get_bool()
+        return pretty_format_upgradeable(
+            install_infos,
+            verbose=self.verbose, color=self.color, print_repo=print_repo
+        )
+
+    def pformat_warned_packages(self):
+        warn_about_packages_str = self.config.ui.WarnAboutPackageUpdates.get_str()
+        warn_about_packages_list: List[InstallInfo] = []
+
+        @overload
+        def remove_globs_from_pkg_list(pkg_list: List[AURInstallInfo]) -> None:
+            ...
+
+        @overload
+        def remove_globs_from_pkg_list(pkg_list: List[RepoInstallInfo]) -> None:
+            ...
+
+        def remove_globs_from_pkg_list(pkg_list):
+            for pkg_install_info in pkg_list[::]:
+                for glob in globs_and_names:
+                    if fnmatch(pkg_install_info.name, glob):
+                        pkg_list.remove(pkg_install_info)
+                        warn_about_packages_list.append(pkg_install_info)
+
+        if warn_about_packages_str:
+            globs_and_names = warn_about_packages_str.split(',')
+            pkg_list: Union[List[RepoInstallInfo], List[AURInstallInfo]]
+            for pkg_list in self.all_install_info_lists:
+                remove_globs_from_pkg_list(pkg_list)
+
+        if warn_about_packages_list:
+            self.result.append('\n{} {} {} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.blue),
+                self._color_line('!!', ColorsHighlight.red),
+                self._color_line(
+                    translate_many(
+                        "WARNING about package installation:",
+                        "WARNING about packages installation:",
+                        len(warn_about_packages_list)
+                    ), ColorsHighlight.red
+                ),
+                self._color_line('!!', ColorsHighlight.red),
+            ))
+            self.result.append(self.pretty_format_upgradeable(warn_about_packages_list))
+
+    def pformat_replacements(self):
+        if self.repo_replacements:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.blue),
+                self._bold_line(translate_many(
+                    "Repository package suggested as a replacement:",
+                    "Repository packages suggested as a replacement:",
+                    len(self.repo_replacements)))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.repo_replacements,
+            ))
+        if self.thirdparty_repo_replacements:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.blue),
+                self._bold_line(translate_many(
+                    "Third-party repository package suggested as a replacement:",
+                    "Third-party repository packages suggested as a replacement:",
+                    len(self.repo_packages_updates)))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.thirdparty_repo_replacements,
+            ))
+
+    def pformat_repo(self):
+        if self.repo_packages_updates:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.blue),
+                self._bold_line(translate_many(
+                    "Repository package will be installed:",
+                    "Repository packages will be installed:",
+                    len(self.repo_packages_updates)))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.repo_packages_updates,
+            ))
+        if self.new_repo_deps:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.yellow),
+                self._bold_line(translate_many(
+                    "New dependency will be installed from repository:",
+                    "New dependencies will be installed from repository:",
+                    len(self.new_repo_deps)
+                ))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.new_repo_deps,
+            ))
+
+    def pformat_thirdaprty_repo(self):
+        if self.thirdparty_repo_packages_updates:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.blue),
+                self._bold_line(translate_many(
+                    "Third-party repository package will be installed:",
+                    "Third-party repository packages will be installed:",
+                    len(self.thirdparty_repo_packages_updates)
+                ))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.thirdparty_repo_packages_updates,
+                print_repo=True
+            ))
+        if self.new_thirdparty_repo_deps:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.yellow),
+                self._bold_line(translate_many(
+                    "New dependency will be installed from third-party repository:",
+                    "New dependencies will be installed from third-party repository:",
+                    len(self.new_thirdparty_repo_deps)
+                ))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.new_thirdparty_repo_deps,
+            ))
+
+    def pformat_aur(self):
+        if self.aur_updates:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.cyan),
+                self._bold_line(translate_many(
+                    "AUR package will be installed:",
+                    "AUR packages will be installed:",
+                    len(self.aur_updates)
+                ))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.aur_updates,
+                print_repo=False
+            ))
+        if self.new_aur_deps:
+            self.result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
+                self._color_line('::', ColorsHighlight.yellow),
+                self._bold_line(translate_many(
+                    "New dependency will be installed from AUR:",
+                    "New dependencies will be installed from AUR:",
+                    len(self.new_aur_deps)
+                ))
+            ))
+            self.result.append(self.pretty_format_upgradeable(
+                self.new_aur_deps,
+                print_repo=False
+            ))
+
+    def pformat_total_size(self):
+        if self.config.sync.ShowDownloadSize.get_bool():
+            self.result.append(
+                '\n' +
+                self._bold_line(translate("Total Download Size:")) +
+                f'{str(round(self.install_info.get_total_download_size(), 2)).rjust(10)} MiB'
+                '\n' +
+                self._bold_line(translate("Total Installed Size:")) +
+                f'{str(round(self.install_info.get_total_installed_size(), 2)).rjust(9)} MiB'
+                '\n'
+            )
+        else:
+            self.result += ['']
+
+    def __call__(self) -> str:
+        self.pformat_warned_packages()
+        self.pformat_replacements()
+        self.pformat_repo()
+        self.pformat_thirdaprty_repo()
+        self.pformat_aur()
+        self.pformat_total_size()
+        return '\n'.join(self.result)
+
+
 def pretty_format_sysupgrade(
         install_info: 'InstallInfoFetcher',
         verbose=False,
         manual_package_selection=False
 ) -> str:
-
-    color = True
-
-    repo_packages_updates = install_info.repo_packages_install_info
-    thirdparty_repo_packages_updates = install_info.thirdparty_repo_packages_install_info
-    aur_updates = install_info.aur_updates_install_info
-    repo_replacements = install_info.repo_replacements_install_info
-    thirdparty_repo_replacements = install_info.thirdparty_repo_replacements_install_info
-
-    new_repo_deps: Optional[List[RepoInstallInfo]] = \
-        install_info.new_repo_deps_install_info
-    new_thirdparty_repo_deps: Optional[List[RepoInstallInfo]] = \
-        install_info.new_thirdparty_repo_deps_install_info
-    new_aur_deps: Optional[List[AURInstallInfo]] = \
-        install_info.aur_deps_install_info
-
-    if manual_package_selection:
-        color = False
-        new_repo_deps = None
-        new_thirdparty_repo_deps = None
-        new_aur_deps = None
-
-    def _color_line(line, *args, **kwargs):
-        return color_line(line, *args, **kwargs) if color else line
-
-    def _bold_line(line):
-        return bold_line(line) if color else line
-
-    result = []
-
-    if repo_replacements:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.blue),
-            _bold_line(translate_many(
-                "Repository package suggested as a replacement:",
-                "Repository packages suggested as a replacement:",
-                len(repo_replacements)))
-        ))
-        result.append(pretty_format_upgradeable(
-            repo_replacements,
-            verbose=verbose, color=color,
-            print_repo=PikaurConfig().sync.AlwaysShowPkgOrigin.get_bool()
-        ))
-    if thirdparty_repo_replacements:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.blue),
-            _bold_line(translate_many(
-                "Third-party repository package suggested as a replacement:",
-                "Third-party repository packages suggested as a replacement:",
-                len(repo_packages_updates)))
-        ))
-        result.append(pretty_format_upgradeable(
-            thirdparty_repo_replacements,
-            verbose=verbose, color=color,
-            print_repo=PikaurConfig().sync.AlwaysShowPkgOrigin.get_bool()
-        ))
-
-    if repo_packages_updates:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.blue),
-            _bold_line(translate_many(
-                "Repository package will be installed:",
-                "Repository packages will be installed:",
-                len(repo_packages_updates)))
-        ))
-        result.append(pretty_format_upgradeable(
-            repo_packages_updates,
-            verbose=verbose, color=color,
-            print_repo=PikaurConfig().sync.AlwaysShowPkgOrigin.get_bool()
-        ))
-    if new_repo_deps:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.yellow),
-            _bold_line(translate_many(
-                "New dependency will be installed from repository:",
-                "New dependencies will be installed from repository:",
-                len(new_repo_deps)
-            ))
-        ))
-        result.append(pretty_format_upgradeable(
-            new_repo_deps,
-            verbose=verbose, color=color,
-            print_repo=PikaurConfig().sync.AlwaysShowPkgOrigin.get_bool()
-        ))
-    if thirdparty_repo_packages_updates:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.blue),
-            _bold_line(translate_many(
-                "Third-party repository package will be installed:",
-                "Third-party repository packages will be installed:",
-                len(thirdparty_repo_packages_updates)
-            ))
-        ))
-        result.append(pretty_format_upgradeable(
-            thirdparty_repo_packages_updates,
-            verbose=verbose, color=color, print_repo=True
-        ))
-    if new_thirdparty_repo_deps:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.yellow),
-            _bold_line(translate_many(
-                "New dependency will be installed from third-party repository:",
-                "New dependencies will be installed from third-party repository:",
-                len(new_thirdparty_repo_deps)
-            ))
-        ))
-        result.append(pretty_format_upgradeable(
-            new_thirdparty_repo_deps,
-            verbose=verbose, color=color,
-            print_repo=PikaurConfig().sync.AlwaysShowPkgOrigin.get_bool()
-        ))
-    if aur_updates:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.cyan),
-            _bold_line(translate_many(
-                "AUR package will be installed:",
-                "AUR packages will be installed:",
-                len(aur_updates)
-            ))
-        ))
-        result.append(pretty_format_upgradeable(
-            aur_updates,
-            verbose=verbose, color=color, print_repo=False
-        ))
-    if new_aur_deps:
-        result.append('\n{} {}'.format(  # pylint: disable=consider-using-f-string
-            _color_line('::', ColorsHighlight.yellow),
-            _bold_line(translate_many(
-                "New dependency will be installed from AUR:",
-                "New dependencies will be installed from AUR:",
-                len(new_aur_deps)
-            ))
-        ))
-        result.append(pretty_format_upgradeable(
-            new_aur_deps,
-            verbose=verbose, color=color, print_repo=False
-        ))
-    if PikaurConfig().sync.ShowDownloadSize.get_bool():
-        result.append(
-            f'\n{_bold_line("Total Download Size:")}'
-            f'{str(round(install_info.get_total_download_size(), 2)).rjust(10)} MiB'
-            f'\n{_bold_line("Total Installed Size:")}'
-            f'{str(round(install_info.get_total_installed_size(), 2)).rjust(9)} MiB\n'
-        )
-    else:
-        result += ['']
-    return '\n'.join(result)
+    return SysupgradePrettyFormatter(
+        install_info=install_info,
+        verbose=verbose,
+        manual_package_selection=manual_package_selection
+    )()
 
 
 def print_ignored_package(
